@@ -27,6 +27,8 @@
 #include <string.h>
 #endif
 
+#include <libxfce4util/libxfce4util.h>
+
 #include "xfconf-cache.h"
 #include "xfconf-channel.h"
 #include "xfconf-errors.h"
@@ -62,7 +64,7 @@
 typedef struct
 {
 #if 0
-    GTimeVal last_used;
+    gint64 last_used;
 #endif
     GValue *value;
 } XfconfCacheItem;
@@ -77,7 +79,7 @@ xfconf_cache_item_new(const GValue *value,
 
     item = g_slice_new0(XfconfCacheItem);
 #if 0
-    g_get_current_time(&item->last_used);
+    item->last_used = g_get_monotonic_time ();
 #endif
 
     if(G_LIKELY(steal)) {
@@ -106,7 +108,7 @@ xfconf_cache_item_update(XfconfCacheItem *item,
         return FALSE;
 
 #if 0
-    g_get_current_time(&item->last_used);
+    item->last_used = g_get_monotonic_time ();
 #endif
 
     if(value) {
@@ -841,8 +843,8 @@ xfconf_cache_set(XfconfCache *cache,
             if(G_LIKELY(g_dbus_error_is_remote_error (tmp_error)))
                 dbus_error_name = g_dbus_error_get_remote_error (tmp_error);
 
-            if(g_strcmp0(dbus_error_name, "org.xfce.Xfconf.Error.PropertyNotFound") != 0
-               && g_strcmp0(dbus_error_name, "org.xfce.Xfconf.Error.ChannelNotFound") != 0)
+            if(g_strcmp0(dbus_error_name, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.PropertyNotFound") != 0
+               && g_strcmp0(dbus_error_name, XFCONF_SERVICE_NAME_PREFIX ".Xfconf.Error.ChannelNotFound") != 0)
             {
                 /* this is bad... */
                 g_propagate_error(error, tmp_error);
